@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.scheduler_v1.services.cloud_scheduler import pagers
@@ -33,11 +31,10 @@ from google.cloud.scheduler_v1.types import cloudscheduler
 from google.cloud.scheduler_v1.types import job
 from google.cloud.scheduler_v1.types import job as gcs_job
 from google.cloud.scheduler_v1.types import target
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as status  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 from .transports.base import CloudSchedulerTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import CloudSchedulerGrpcAsyncIOTransport
 from .client import CloudSchedulerClient
@@ -57,31 +54,26 @@ class CloudSchedulerAsyncClient:
     parse_job_path = staticmethod(CloudSchedulerClient.parse_job_path)
     topic_path = staticmethod(CloudSchedulerClient.topic_path)
     parse_topic_path = staticmethod(CloudSchedulerClient.parse_topic_path)
-
     common_billing_account_path = staticmethod(
         CloudSchedulerClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         CloudSchedulerClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(CloudSchedulerClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         CloudSchedulerClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         CloudSchedulerClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         CloudSchedulerClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(CloudSchedulerClient.common_project_path)
     parse_common_project_path = staticmethod(
         CloudSchedulerClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(CloudSchedulerClient.common_location_path)
     parse_common_location_path = staticmethod(
         CloudSchedulerClient.parse_common_location_path
@@ -89,7 +81,8 @@ class CloudSchedulerAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -104,7 +97,7 @@ class CloudSchedulerAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -121,7 +114,7 @@ class CloudSchedulerAsyncClient:
 
     @property
     def transport(self) -> CloudSchedulerTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             CloudSchedulerTransport: The transport used by the client instance.
@@ -135,12 +128,12 @@ class CloudSchedulerAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, CloudSchedulerTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the cloud scheduler client.
+        """Instantiates the cloud scheduler client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -172,7 +165,6 @@ class CloudSchedulerAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = CloudSchedulerClient(
             credentials=credentials,
             transport=transport,
@@ -203,7 +195,6 @@ class CloudSchedulerAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -233,7 +224,6 @@ class CloudSchedulerAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -246,7 +236,8 @@ class CloudSchedulerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -294,7 +285,6 @@ class CloudSchedulerAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -322,7 +312,6 @@ class CloudSchedulerAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -335,7 +324,8 @@ class CloudSchedulerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -391,7 +381,6 @@ class CloudSchedulerAsyncClient:
                 This corresponds to the ``job`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -419,7 +408,6 @@ class CloudSchedulerAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if job is not None:
@@ -450,7 +438,7 @@ class CloudSchedulerAsyncClient:
         request: cloudscheduler.UpdateJobRequest = None,
         *,
         job: gcs_job.Job = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -491,7 +479,6 @@ class CloudSchedulerAsyncClient:
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -519,7 +506,6 @@ class CloudSchedulerAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if job is not None:
             request.job = job
         if update_mask is not None:
@@ -568,7 +554,6 @@ class CloudSchedulerAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -589,7 +574,6 @@ class CloudSchedulerAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -602,7 +586,8 @@ class CloudSchedulerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -654,7 +639,6 @@ class CloudSchedulerAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -682,7 +666,6 @@ class CloudSchedulerAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -738,7 +721,6 @@ class CloudSchedulerAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -766,7 +748,6 @@ class CloudSchedulerAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -815,7 +796,6 @@ class CloudSchedulerAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -843,7 +823,6 @@ class CloudSchedulerAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
