@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,22 +13,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import abc
-import typing
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
+import packaging.version
 import pkg_resources
 
-from google import auth  # type: ignore
-from google.api_core import exceptions  # type: ignore
+import google.auth  # type: ignore
+import google.api_core  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.scheduler_v1beta1.types import cloudscheduler
 from google.cloud.scheduler_v1beta1.types import job
 from google.cloud.scheduler_v1beta1.types import job as gcs_job
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -38,27 +38,40 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
+try:
+    # google.auth.__version__ was added in 1.26.0
+    _GOOGLE_AUTH_VERSION = google.auth.__version__
+except AttributeError:
+    try:  # try pkg_resources if it is available
+        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
+    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
+        _GOOGLE_AUTH_VERSION = None
+
 
 class CloudSchedulerTransport(abc.ABC):
     """Abstract transport class for CloudScheduler."""
 
     AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)
 
+    DEFAULT_HOST: str = "cloudscheduler.googleapis.com"
+
     def __init__(
         self,
         *,
-        host: str = "cloudscheduler.googleapis.com",
-        credentials: credentials.Credentials = None,
-        credentials_file: typing.Optional[str] = None,
-        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
-        quota_project_id: typing.Optional[str] = None,
+        host: str = DEFAULT_HOST,
+        credentials: ga_credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -67,7 +80,7 @@ class CloudSchedulerTransport(abc.ABC):
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is mutually exclusive with credentials.
-            scope (Optional[Sequence[str]]): A list of scopes.
+            scopes (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
             client_info (google.api_core.gapic_v1.client_info.ClientInfo):
@@ -75,35 +88,70 @@ class CloudSchedulerTransport(abc.ABC):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
         self._host = host
 
+        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+
         # Save the scopes.
-        self._scopes = scopes or self.AUTH_SCOPES
+        self._scopes = scopes
 
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
-            raise exceptions.DuplicateCredentialArgs(
+            raise core_exceptions.DuplicateCredentialArgs(
                 "'credentials_file' and 'credentials' are mutually exclusive"
             )
 
         if credentials_file is not None:
-            credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=self._scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.load_credentials_from_file(
+                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
-            credentials, _ = auth.default(
-                scopes=self._scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.default(
+                **scopes_kwargs, quota_project_id=quota_project_id
             )
 
+        # If the credentials is service account credentials, then always try to use self signed JWT.
+        if (
+            always_use_jwt_access
+            and isinstance(credentials, service_account.Credentials)
+            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
+        ):
+            credentials = credentials.with_always_use_jwt_access(True)
+
         # Save the credentials.
         self._credentials = credentials
 
+    # TODO(busunkim): This method is in the base transport
+    # to avoid duplicating code across the transport classes. These functions
+    # should be deleted once the minimum required versions of google-auth is increased.
+
+    # TODO: Remove this function once google-auth >= 1.25.0 is required
+    @classmethod
+    def _get_scopes_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Optional[Sequence[str]]]:
+        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
+
+        scopes_kwargs = {}
+
+        if _GOOGLE_AUTH_VERSION and (
+            packaging.version.parse(_GOOGLE_AUTH_VERSION)
+            >= packaging.version.parse("1.25.0")
+        ):
+            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
+        else:
+            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
+
+        return scopes_kwargs
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -114,7 +162,8 @@ class CloudSchedulerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=600.0,
                 ),
@@ -128,7 +177,8 @@ class CloudSchedulerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=600.0,
                 ),
@@ -148,7 +198,8 @@ class CloudSchedulerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=600.0,
                 ),
@@ -162,7 +213,8 @@ class CloudSchedulerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=600.0,
                 ),
@@ -176,7 +228,8 @@ class CloudSchedulerTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
                     deadline=600.0,
                 ),
@@ -191,11 +244,10 @@ class CloudSchedulerTransport(abc.ABC):
     @property
     def list_jobs(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [cloudscheduler.ListJobsRequest],
-        typing.Union[
-            cloudscheduler.ListJobsResponse,
-            typing.Awaitable[cloudscheduler.ListJobsResponse],
+        Union[
+            cloudscheduler.ListJobsResponse, Awaitable[cloudscheduler.ListJobsResponse]
         ],
     ]:
         raise NotImplementedError()
@@ -203,62 +255,52 @@ class CloudSchedulerTransport(abc.ABC):
     @property
     def get_job(
         self,
-    ) -> typing.Callable[
-        [cloudscheduler.GetJobRequest], typing.Union[job.Job, typing.Awaitable[job.Job]]
-    ]:
+    ) -> Callable[[cloudscheduler.GetJobRequest], Union[job.Job, Awaitable[job.Job]]]:
         raise NotImplementedError()
 
     @property
     def create_job(
         self,
-    ) -> typing.Callable[
-        [cloudscheduler.CreateJobRequest],
-        typing.Union[gcs_job.Job, typing.Awaitable[gcs_job.Job]],
+    ) -> Callable[
+        [cloudscheduler.CreateJobRequest], Union[gcs_job.Job, Awaitable[gcs_job.Job]]
     ]:
         raise NotImplementedError()
 
     @property
     def update_job(
         self,
-    ) -> typing.Callable[
-        [cloudscheduler.UpdateJobRequest],
-        typing.Union[gcs_job.Job, typing.Awaitable[gcs_job.Job]],
+    ) -> Callable[
+        [cloudscheduler.UpdateJobRequest], Union[gcs_job.Job, Awaitable[gcs_job.Job]]
     ]:
         raise NotImplementedError()
 
     @property
     def delete_job(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [cloudscheduler.DeleteJobRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def pause_job(
         self,
-    ) -> typing.Callable[
-        [cloudscheduler.PauseJobRequest],
-        typing.Union[job.Job, typing.Awaitable[job.Job]],
-    ]:
+    ) -> Callable[[cloudscheduler.PauseJobRequest], Union[job.Job, Awaitable[job.Job]]]:
         raise NotImplementedError()
 
     @property
     def resume_job(
         self,
-    ) -> typing.Callable[
-        [cloudscheduler.ResumeJobRequest],
-        typing.Union[job.Job, typing.Awaitable[job.Job]],
+    ) -> Callable[
+        [cloudscheduler.ResumeJobRequest], Union[job.Job, Awaitable[job.Job]]
     ]:
         raise NotImplementedError()
 
     @property
     def run_job(
         self,
-    ) -> typing.Callable[
-        [cloudscheduler.RunJobRequest], typing.Union[job.Job, typing.Awaitable[job.Job]]
-    ]:
+    ) -> Callable[[cloudscheduler.RunJobRequest], Union[job.Job, Awaitable[job.Job]]]:
         raise NotImplementedError()
 
 
